<?php
/**
 * Updater Functions
 * 
 * @package Album and Image Gallery Plus Lightbox Pro
 * @since 1.0.0
 */

global $aigpl_pro_license_info;

if( ! defined( 'AIGPL_PRO_LICENSE_URL' ) ) {
	define( 'AIGPL_PRO_LICENSE_URL', add_query_arg(array( 'post_type' => AIGPL_PRO_POST_TYPE, 'page' => 'aigpl-license'), admin_url('edit.php')) ); // License page URL
}

// Taking some data
$current_date	= current_time( 'mysql' );
$license 		= get_option( 'aigpl_pro_plugin_license_key' );
$license_info	= get_option( 'aigpl_pro_plugin_license_info' );

if( isset( $license_info->expires ) && $license_info->expires != 'lifetime' && $current_date > $license_info->expires ) {

	$renew_link		= add_query_arg( array('edd_license_key' => $license, 'download_id' => $license_info->payment_id), 'https://www.wponlinesupport.com/checkout/' );
	$license_msg	= sprintf(
							__( 'Your license key expired on %s. Kindly <a href="%s" target="_blank">renew</a> it for further updates and support from your <a href="%s" target="_blank">account page</a>.', 'album-and-image-gallery-plus-lightbox' ),
							date_i18n( get_option( 'date_format' ), strtotime( $license_info->expires, current_time( 'timestamp' ) ) ),
							$renew_link,
							'https://www.wponlinesupport.com/my-account/?tab=license-keys'
					);

	$license_info->license_status	= 'expired';
	$license_info->license_msg		= $license_msg;

} else if( isset( $license_info->license ) ) {
	
	$license_info->license_status = $license_info->license;
}

$aigpl_pro_license_info = $license_info; // Assign to global variable

/**
 * Updater Menu Function
 * 
 * @since 1.0.0
 */
function aigpl_pro_plugin_license_menu() {

	global $aigpl_pro_license_info;

	// Getting license status to show notification
	$license_info 	= $aigpl_pro_license_info;
	$status 		= ! empty( $license_info->license_status ) ? $license_info->license_status : false;
	$notification 	= ( $status !== 'valid' ) ? ' <span class="update-plugins count-1"><span class="plugin-count" aria-hidden="true">1</span></span>' : '';

	add_submenu_page( 'edit.php?post_type='.AIGPL_PRO_POST_TYPE, __('Album and Image Gallery Plus Lightbox Pro', 'album-and-image-gallery-plus-lightbox'), __('Plugin License', 'album-and-image-gallery-plus-lightbox').$notification, 'manage_options', 'aigpl-license', 'aigpl_pro_plugin_license_page' );
}
add_action('admin_menu', 'aigpl_pro_plugin_license_menu', 30);

/**
 * Plugin license form HTML
 * 
 * @since 1.0.0
 */
function aigpl_pro_plugin_license_page() {

	global $aigpl_pro_license_info;

	$license_info 	= $aigpl_pro_license_info;
	$license 		= get_option( 'aigpl_pro_plugin_license_key' );
	$status 		= ! empty( $license_info->license_status )	? $license_info->license_status : false;
	$payment_id		= ! empty( $license_info->payment_id )		? $license_info->payment_id		: false;
?>
	<div class="wrap">
		<h2><?php _e('Album and Image Gallery Plus Lightbox Pro - License', 'album-and-image-gallery-plus-lightbox'); ?></h2>
		<form method="post" action="options.php">

			<?php settings_fields('aigpl_pro_plugin_license_sett'); ?>

			<?php if( isset($_GET['settings-updated']) && $_GET['settings-updated'] == 'true' ) { ?>
				<div class="updated notice is-dismissible" id="message">
					<p><?php _e('Your changes saved successfully.', 'album-and-image-gallery-plus-lightbox'); ?></p>
				</div>
			<?php } elseif ( isset($_GET['sl_activation']) && $_GET['sl_activation'] == 'false' && !empty($_GET['message']) ) { ?>
				<div class="error" id="message">
					<p><?php echo urldecode($_GET['message']); ?></p>
				</div>
			<?php }

			if( $status !== false && $status == 'valid' ) { ?>
				<div class="updated notice notice-success" id="message">
					<p><?php _e('Plugin license is active.', 'album-and-image-gallery-plus-lightbox'); ?></p>
				</div>
			<?php } elseif( ! isset( $_GET['sl_activation'] ) ) { ?>
				<div class="error notice notice-error" id="message">
					<p><?php _e('Please activate plugin license to get automatic update of plugin.', 'album-and-image-gallery-plus-lightbox'); ?></p>
				</div>
			<?php } ?>

			<table class="form-table">
				<tbody>
					<tr valign="top">
						<th scope="row" valign="top">
							<label for="aigpl-pro-plugin-license-key"><?php _e('License Key', 'album-and-image-gallery-plus-lightbox'); ?></label>
						</th>
						<td>
							<input name="aigpl_pro_plugin_license_key" id="aigpl-pro-plugin-license-key" type="password" class="regular-text" value="<?php esc_attr_e( $license ); ?>" /><br/>
							<span class="description"><?php _e('Enter plugin license key.', 'album-and-image-gallery-plus-lightbox'); ?></span>
						</td>
					</tr>
					<?php if( false !== $license ) { ?>
						<tr valign="top">
							<th scope="row" valign="top">
								<?php _e('Activate License', 'album-and-image-gallery-plus-lightbox'); ?>
							</th>
							<td>
								<?php wp_nonce_field( 'edd_aigpl_pro_nonce', 'edd_aigpl_pro_nonce' );

								if( $status !== false && $status == 'valid' ) { ?>	
									<input type="submit" class="button-secondary" name="aigpl_pro_license_deactivate" value="<?php _e('Deactivate License', 'album-and-image-gallery-plus-lightbox'); ?>"/>
									<span style="color: green; display: inline-block; margin: 4px 0px 0px;"><i class="dashicons dashicons-yes"></i><?php _e('Active', 'album-and-image-gallery-plus-lightbox'); ?></span>
								<?php } else { ?>
									<input type="submit" class="button button-secondary" name="aigpl_pro_license_activate" value="<?php _e('Activate License', 'album-and-image-gallery-plus-lightbox'); ?>"/>
								<?php } ?>
							</td>
						</tr>
					<?php } ?>

					<?php if( $license && $license_info ) { ?>
						<tr>
							<th valign="top"><?php esc_html_e('License Information', 'album-and-image-gallery-plus-lightbox'); ?></th>
							<?php if( $status == 'valid' ) { ?>
							<td style="font-weight: 600; line-height: 25px;">
								<p style="color:green;"><?php echo $license_info->license_msg; ?></p>

								<?php
								if( ! defined( 'WPOS_HIDE_LICENSE' ) || ( defined( 'WPOS_HIDE_LICENSE' ) && WPOS_HIDE_LICENSE != 'info' ) ) {

									echo esc_html__('License Limit' , 'album-and-image-gallery-plus-lightbox') ." : ". ( (isset($license_info->license_limit) && $license_info->license_limit == 0) ? __('Unlimited', 'album-and-image-gallery-plus-lightbox') : $license_info->license_limit ) ." ". esc_html__('Sites', 'album-and-image-gallery-plus-lightbox') . '<br/>';
									echo esc_html__('Active Site(s)' , 'album-and-image-gallery-plus-lightbox') ." : ". ( isset($license_info->site_count) ? $license_info->site_count : 'N/A' ) . '<br/>';
									echo esc_html__('Activations Left Site(s)' , 'album-and-image-gallery-plus-lightbox') ." : ". ( isset($license_info->activations_left) ? ucfirst($license_info->activations_left) : 'N/A' ) . '<br/>';
									
									if( isset( $license_info->expires ) && $license_info->expires == 'lifetime' ) {
										echo esc_html__('Valid Upto' , 'album-and-image-gallery-plus-lightbox') ." : ". esc_html__( 'Lifetime', 'album-and-image-gallery-plus-lightbox' ) . '<br/>';
									} else {
										echo esc_html__('Valid Upto' , 'album-and-image-gallery-plus-lightbox') ." : ". date('d M, Y', strtotime($license_info->expires)) . ' <label style="vertical-align:top;" title="'.esc_html__('On purchase of any product 1 Year of Updates, 1 Year of Expert Support. After 1 Year, use without renewal OR renew manually at discounted price for further updates and support.', 'album-and-image-gallery-plus-lightbox').'">[?]</label> <br/>';
									}

									echo esc_html__('Purchase ID' , 'album-and-image-gallery-plus-lightbox') ." : #". $license_info->payment_id;
								}
								?>
							</td>
							<?php } else if( $status != 'valid' && isset( $license_info->license_msg ) ) { ?>
							<td style="font-weight: 600;">
								<p style="color:#dc3232;"><?php echo $license_info->license_msg; ?></p>
							</td>
							<?php } ?>
						</tr>
					<?php } ?>
				</tbody>
			</table>
			<?php submit_button(); ?>

			<div class="wpo-activate-step">
				<hr/>
				<h2><?php esc_html_e('Steps to Activate the License', 'album-and-image-gallery-plus-lightbox'); ?></h2>
				<ol>
					<li><?php esc_html_e("Enter your license key into 'License Key' field and press 'Save Changes' button.", 'album-and-image-gallery-plus-lightbox'); ?></li>
					<li><?php esc_html_e("After save changes you can see an another button named 'Activate License'.", 'album-and-image-gallery-plus-lightbox'); ?></li>
					<li><?php esc_html_e("Press 'Activate License'. If your key is valid then you can see green 'Active' text.", 'album-and-image-gallery-plus-lightbox'); ?></li>
					<li><?php esc_html_e("That's it. Now you can get auto update of this plugin.", 'album-and-image-gallery-plus-lightbox'); ?></li>
				</ol>
				<h4 style="color:#dc3232;"><?php esc_html_e('Note: If you do not activate the license then you will not get automatic update of this plugin any more.', 'album-and-image-gallery-plus-lightbox'); ?></h4>
				<h4><?php esc_html_e('You will receive license key within your product purchase email. If you do not have license key then you can get it from your', 'album-and-image-gallery-plus-lightbox'); ?> <a href="https://www.wponlinesupport.com/my-account/" target="_blank"><?php esc_html_e('Account page', 'album-and-image-gallery-plus-lightbox'); ?></a>.</h4>
				<h4><?php esc_html_e('Note : If your license key has expired, please renew your license from', 'album-and-image-gallery-plus-lightbox'); ?> <a href="https://www.wponlinesupport.com/my-account/" target="_blank"><?php esc_html_e('Account page', 'album-and-image-gallery-plus-lightbox'); ?></a>.</h4>
			</div><!-- end .wpo-activate-step -->
		</form>
	</div><!-- end .wrap -->
<?php
}

/**
 * Validate plugin license options
 * 
 * @since 1.0
 */
function aigpl_pro_sanitize_license( $new ) {

	$old = get_option( 'aigpl_pro_plugin_license_key' );

	if( $old && $old != $new ) {
		update_option( 'aigpl_pro_plugin_license_info', '', false ); // new license has been entered, so must reactivate
	}
	return $new;
}

/**
 * Register plugin license settings
 * 
 * @since 1.0.0
 */
function aigpl_pro_process_plugin_license() {

	// Register plugin license settings
	register_setting('aigpl_pro_plugin_license_sett', 'aigpl_pro_plugin_license_key', 'aigpl_pro_sanitize_license' );

	/***** Activate Plugin License *****/
	if( isset( $_POST['aigpl_pro_license_activate'] ) ) {

		// run a quick security check
	 	if( ! check_admin_referer( 'edd_aigpl_pro_nonce', 'edd_aigpl_pro_nonce' ) ) {
			return; // get out if we didn't click the Activate button
	 	}

		// retrieve the license from the database
		$license_msg	= sprintf( __('Sorry, Something happened wrong. Please contact <a href="%s">site administrator</a>.', 'album-and-image-gallery-plus-lightbox'), EDD_AIGPL_PRO_STORE_URL );
		$license		= trim( get_option( 'aigpl_pro_plugin_license_key' ) );
		$post_license	= isset( $_POST['aigpl_pro_plugin_license_key'] ) ? trim( $_POST['aigpl_pro_plugin_license_key'] ) : '';

		// Update license key if user directly press active button
		if( $post_license != $license ) {
			update_option( 'aigpl_pro_plugin_license_key', $post_license );
			$license = $post_license;
		}

		// data to send in our API request
		$api_params = array(
			'edd_action'=> 'activate_license',
			'license' 	=> $license,
			'item_name' => urlencode( EDD_AIGPL_PRO_ITEM_NAME ), // the name of our product in EDD
			'url'       => home_url()
		);

		// Call the custom API.
		$response = wp_remote_post( EDD_AIGPL_PRO_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// make sure the response came back okay
		if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {

			if ( is_wp_error( $response ) ) {
				$message = $response->get_error_message();
			} else {
				$message = __( 'An error occurred, please try again.', 'album-and-image-gallery-plus-lightbox' );
			}

		} else {

			$license_data = json_decode( wp_remote_retrieve_body( $response ) );

			if ( false === $license_data->success ) {

				switch( $license_data->error ) {

					case 'expired' :

						$renew_link	= add_query_arg( array('edd_license_key' => $license, 'download_id' => $license_data->payment_id), 'https://www.wponlinesupport.com/checkout/' );
						$message	= sprintf(
											__( 'Your license key expired on %s.', 'album-and-image-gallery-plus-lightbox' ),
											date_i18n( get_option( 'date_format' ), strtotime( $license_data->expires, current_time( 'timestamp' ) ) )
										);

						$license_msg = $message;
						$license_msg .= '<br/>' . sprintf( __('Kindly <a href="%s" target="_blank">renew</a> it for further updates and support from your <a href="%s" target="_blank">account page</a>.', 'album-and-image-gallery-plus-lightbox'), $renew_link, 'https://www.wponlinesupport.com/my-account/?tab=license-keys' );
						break;

					case 'revoked' :
					case 'disabled' :

						$message		= __( 'Your license key has been disabled.', 'album-and-image-gallery-plus-lightbox' );
						$license_msg	= sprintf( __('Your license key has been disabled. Please contact <a href="%s">site administrator</a>.', 'album-and-image-gallery-plus-lightbox'), EDD_AIGPL_PRO_STORE_URL );
						break;

					case 'missing' :

						$message		= __( 'Plugin license is invalid. Please be sure you have entered right plugin license key.', 'album-and-image-gallery-plus-lightbox' );
						$license_msg	= $message;
						break;

					case 'invalid' :
					case 'site_inactive' :

						$message		= __( 'Your license is not active for this URL.', 'album-and-image-gallery-plus-lightbox' );
						$license_msg	= $message;
						break;

					case 'item_name_mismatch' :

						$message		= sprintf( __( 'This appears to be an invalid license key for %s.', 'album-and-image-gallery-plus-lightbox' ), EDD_AIGPL_PRO_ITEM_NAME );
						$license_msg	= $message;
						break;

					case 'no_activations_left':

						$message		= __( 'Your license key has reached its activation limit.', 'album-and-image-gallery-plus-lightbox' );
						$license_msg	= sprintf( __('Sorry, Something happened wrong. Please contact <a href="%s">site administrator</a>.', 'album-and-image-gallery-plus-lightbox'), EDD_AIGPL_PRO_STORE_URL );
						break;

					default :

						$message		= __( 'An error occurred, please try again.', 'album-and-image-gallery-plus-lightbox' );
						$license_msg	= $message;
						break;
				}

			} else {
				$license_msg = __( 'License is activated successfully.', 'album-and-image-gallery-plus-lightbox' );
			}
		}

		// $license_data->license will be either "valid" or "invalid"
		if( isset( $license_data->license ) ) {
			$license_data->license_msg = $license_msg;
			update_option( 'aigpl_pro_plugin_license_info', $license_data, false );
		}

		// Check if anything passed on a message constituting a failure
		if ( ! empty( $message ) ) {
			$redirect = add_query_arg( array( 'sl_activation' => 'false', 'message' => urlencode( $message ) ), AIGPL_PRO_LICENSE_URL );
			wp_redirect( $redirect );
			exit();
		}

		wp_redirect( AIGPL_PRO_LICENSE_URL );
		exit();
	}

	/***** Deactivate Plugin License *****/
	// listen for our activate button to be clicked
	if( isset( $_POST['aigpl_pro_license_deactivate'] ) ) {

		// run a quick security check
	 	if( ! check_admin_referer( 'edd_aigpl_pro_nonce', 'edd_aigpl_pro_nonce' ) ) {
			return; // get out if we didn't click the Activate button
	 	}

		// retrieve the license from the database
		$license = trim( get_option( 'aigpl_pro_plugin_license_key' ) );

		// data to send in our API request
		$api_params = array(
			'edd_action'=> 'deactivate_license',
			'license' 	=> $license,
			'item_name' => urlencode( EDD_AIGPL_PRO_ITEM_NAME ), // the name of our product in EDD
			'url'       => home_url()
		);

		// Call the custom API.
		$response = wp_remote_post( EDD_AIGPL_PRO_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// make sure the response came back okay
		if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {

			if ( is_wp_error( $response ) ) {
				$message = $response->get_error_message();
			} else {
				$message = __( 'An error occurred, please try again.', 'album-and-image-gallery-plus-lightbox' );
			}

			$redirect = add_query_arg( array( 'sl_activation' => 'false', 'message' => urlencode( $message ) ), AIGPL_PRO_LICENSE_URL );

			wp_redirect( $redirect );
			exit();
		}

		// decode the license data
		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		// $license_data->license will be either "deactivated" or "failed"
		if( $license_data->license == 'deactivated' || $license_data->license == 'failed' ) {
			update_option( 'aigpl_pro_plugin_license_info', '', false );
		}

		wp_redirect( AIGPL_PRO_LICENSE_URL );
		exit();
	}
}
add_action('admin_init', 'aigpl_pro_process_plugin_license');

/**
 * Function to add license plugins link
 * 
 * @since 1.0
 */
function aigpl_pro_plugin_action_links( $links ) {
	
	$links['license'] = '<a href="' . esc_url(AIGPL_PRO_LICENSE_URL) . '" title="' . esc_attr( __( 'Activate Plugin License', 'album-and-image-gallery-plus-lightbox' ) ) . '">' . __( 'License', 'album-and-image-gallery-plus-lightbox' ) . '</a>';
	
	return $links;
}
add_filter( 'plugin_action_links_' . AIGPL_PRO_PLUGIN_BASENAME, 'aigpl_pro_plugin_action_links' );

/**
 * Displays message inline on plugin row that the license key is missing
 *
 * @since 1.0
 */
function aigpl_pro_plugin_row_license_missing( $plugin_data, $version_info ) {

	global $aigpl_pro_license_info;

	$license_info 	= $aigpl_pro_license_info;
	$license_status = ! empty( $license_info->license_status ) ? $license_info->license_status : false;

	if( ( empty( $license_info ) || $license_status !== 'valid' ) ) {
		echo '&nbsp;<strong><a href="' . esc_url( AIGPL_PRO_LICENSE_URL ) . '">' . esc_html__( 'Enter valid license key for automatic updates.', 'album-and-image-gallery-plus-lightbox' ) . '</a></strong>';
	}
}
add_action( 'in_plugin_update_message-' . AIGPL_PRO_PLUGIN_BASENAME, 'aigpl_pro_plugin_row_license_missing', 10, 2 );

/**
 * Displays license expired message on plugin row
 *
 * @since 1.0
 */
function aigpl_pro_plugin_license_msg( $file, $plugin_data ) {

	global $aigpl_pro_license_info;

	$plugin_slug    = isset( $plugin_data['slug'] )						? $plugin_data['slug']						: sanitize_title( $plugin_data['Name'] );
	$license_status = ! empty( $aigpl_pro_license_info->license_status ) ? $aigpl_pro_license_info->license_status	: false;
	$license_msg	= ! empty( $aigpl_pro_license_info->license_msg )	? $aigpl_pro_license_info->license_msg		: '';

	if( $license_status == 'expired' && $license_msg && ! isset( $plugin_data['update'] ) ) {

		echo '<tr id="'.$plugin_slug.'-update" class="plugin-update-tr active" data-slug="'. $plugin_slug .'" data-plugin="'.$file.'">
				<td class="plugin-update colspanchange" colspan="4">
					<div class="update-message notice inline notice-error notice-alt"><p>'. $license_msg .'</p></div>

					<script type="text/javascript"> 
						jQuery("#'.$plugin_slug.'-update").prev("tr").addClass("update"); 
					</script>
				</td>
			</tr>';
	}
}
add_action( 'after_plugin_row_' . AIGPL_PRO_PLUGIN_BASENAME, 'aigpl_pro_plugin_license_msg', 10, 2 );

/**
 * Function to add license expired notice
 * 
 * @since 1.0
 */
function aigpl_pro_plugin_license_notice() {

	global $typenow, $aigpl_pro_license_info;

	// If not plugin screen then return
	if( $typenow != AIGPL_PRO_POST_TYPE ) {
		return false;
	}

	$notice_transient = get_transient( 'aigpl_pro_license_exp_notice' );
	
	// If plugin license is dismissed
	if( $notice_transient !== false ) {
		return false;
	}

	$license_info	= $aigpl_pro_license_info;
	$license_status = ! empty( $license_info->license_status )	? $license_info->license_status : false;
	$license_msg	= ! empty( $license_info->license_msg )		? $license_info->license_msg	: false;

	if( $license_status == 'expired' ) {

		$notice_link = add_query_arg( array('message' => 'aigpl-pro-license-exp-notice') );

		echo '<div class="error notice notice-error" style="position:relative;">
				<p>'. $license_msg .'</p>
				<a href="'.esc_url( $notice_link ).'" class="notice-dismiss" style="text-decoration:none;"></a>
			</div>';
	}
}
add_action( 'admin_notices', 'aigpl_pro_plugin_license_notice' );