<?php
/**
 * Pro Designs and Plugins Feed 
 *
 * @package Album and Image Gallery Plus Lightbox Pro 
 * @since 1.1
 */

if ( !defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

// Action to add menu
add_action('admin_menu', 'aigpl_pro_register_design_page');

/**
 * Register plugin design page in admin menu
 * 
 * @package Album and Image Gallery Plus Lightbox Pro
 * @since 1.1
 */ 
function aigpl_pro_register_design_page() {
	add_submenu_page( 'edit.php?post_type='.AIGPL_PRO_POST_TYPE, __('Getting Started - Album and Image Gallery Plus Lightbox Pro', 'album-and-image-gallery-plus-lightbox'), __('Getting Started', 'album-and-image-gallery-plus-lightbox'), 'edit_posts', 'aigpl-designs', 'aigpl_pro_designs_page' );
}

/**
 * Function to display plugin design HTML
 * 
 * @package Album and Image Gallery Plus Lightbox Pro
 * @since 1.1
 */
function aigpl_pro_designs_page() {

	$wpos_feed_tabs = aigpl_pro_help_tabs();
	$active_tab 	= isset($_GET['tab']) ? $_GET['tab'] : 'how-it-work';
?>

	<div class="wrap aigpl-wrap">

		<h2 class="nav-tab-wrapper">
			<?php
			foreach ($wpos_feed_tabs as $tab_key => $tab_val) {
				$tab_name	= $tab_val['name'];
				$active_cls = ($tab_key == $active_tab) ? 'nav-tab-active' : '';
				$tab_link 	= add_query_arg( array( 'post_type' => AIGPL_PRO_POST_TYPE, 'page' => 'aigpl-designs', 'tab' => $tab_key), admin_url('edit.php') );
			?>

			<a class="nav-tab <?php echo $active_cls; ?>" href="<?php echo esc_url($tab_link); ?>"><?php echo $tab_name; ?></a>

			<?php } ?>
		</h2>

		<div class="aigpl-tab-cnt-wrp">
		<?php
			if( isset($active_tab) && $active_tab == 'how-it-work' ) {
				aigpl_pro_howitwork_page();
			}
		?>
		</div><!-- end .aigpl-tab-cnt-wrp -->

	</div><!-- end .aigpl-wrap -->

<?php
}

/**
 * Function to get plugin feed tabs
 *
 * @package Album and Image Gallery Plus Lightbox Pro
 * @since 1.1
 */
function aigpl_pro_help_tabs() {
	$wpos_feed_tabs = array(
						'how-it-work' 	=> array(
													'name' => __('How It Works', 'album-and-image-gallery-plus-lightbox'),
												),
					);
	return $wpos_feed_tabs;
}

/**
 * Function to get 'How It Works' HTML
 *
 * @package Album and Image Gallery Plus Lightbox Pro
 * @since 1.1
 */
function aigpl_pro_howitwork_page() { 
	$shrt_mapper = add_query_arg( array('post_type' => AIGPL_PRO_POST_TYPE, 'page' => 'aigpl-shrt-mapper'), admin_url('edit.php') );
	?>

	<style type="text/css">
		.wpos-pro-box .hndle{background-color:#0073AA; color:#fff;}
		.wpos-pro-box.postbox{background:#dbf0fa none repeat scroll 0 0; border:1px solid #0073aa; color:#191e23;}
		.aigpl-wrap .wpos-button-full{display:block; text-align:center; box-shadow:none; border-radius:0;}
		.aigpl-shortcode-preview{background-color: #e7e7e7; font-weight: bold; padding: 2px 5px; display: inline-block; margin:0 0 2px 0;}
		.wpos-copy-clipboard{-webkit-touch-callout: all; -webkit-user-select: all; -khtml-user-select: all; -moz-user-select: all; -ms-user-select: all; user-select: all;}
	</style>

	<div id="poststuff">
		<div id="post-body" class="metabox-holder columns-2">

			<!--How it workd HTML -->
			<div id="post-body-content">
				<div class="meta-box-sortables">
					<div class="postbox">

						<h3 class="hndle">
							<span><?php _e( 'How It Works - Display and Shortcode', 'album-and-image-gallery-plus-lightbox' ); ?></span>
						</h3>

						<div class="inside">
							<table class="form-table">
								<tbody>
									<tr>
										<th>
											<label><?php _e('Getting Started', 'album-and-image-gallery-plus-lightbox'); ?></label>
										</th>
										<td>
											<ul>
												<li><?php _e('Step-1. Go to "Album Gallery Pro --> Add Album Gallery tab".', 'album-and-image-gallery-plus-lightbox'); ?></li>
												<li><?php _e('Step-2. Add Album title, description and images under Album and Image Gallery Plus Lightbox Pro - Settings.', 'album-and-image-gallery-plus-lightbox'); ?></li>
												<li><?php _e('Step-3. Under "Choose Gallery Images" click on "Gallery Images" button and select multiple images from WordPress media and click on "Add to Gallery" button.', 'album-and-image-gallery-plus-lightbox'); ?></li>
												<li><?php _e('Step-4. You can find out shortcode for album under "Album Gallery" list view.', 'album-and-image-gallery-plus-lightbox'); ?></li>
											</ul>
										</td>
									</tr>

									<tr>
										<th>
											<label><?php _e('How Shortcode Works', 'album-and-image-gallery-plus-lightbox'); ?></label>
										</th>
										<td>
											<ul>
												<li><?php _e('Step-1. Create a page like Album OR My Album.', 'album-and-image-gallery-plus-lightbox'); ?></li>
												<li><?php _e('Step-2. Put below shortcode as per your need.', 'album-and-image-gallery-plus-lightbox'); ?></li>
											</ul>
										</td>
									</tr>

									<tr>
										<th>
											<label><?php _e('All Shortcodes', 'album-and-image-gallery-plus-lightbox'); ?></label>
										</th>
										<td>
											<span class="wpos-copy-clipboard aigpl-shortcode-preview">[aigpl-gallery]</span> – <?php _e('Gallery Grid Shortcode', 'album-and-image-gallery-plus-lightbox'); ?> <br />
											<span class="wpos-copy-clipboard aigpl-shortcode-preview">[aigpl-gallery-slider]</span> – <?php _e('Gallery Slider Shortcode', 'album-and-image-gallery-plus-lightbox'); ?> <br />
											<span class="wpos-copy-clipboard aigpl-shortcode-preview">[aigpl-gallery-album]</span> – <?php _e('Image Album Grid Shortcode', 'album-and-image-gallery-plus-lightbox'); ?> <br />
											<span class="wpos-copy-clipboard aigpl-shortcode-preview">[aigpl-gallery-album-slider]</span> – <?php _e('Image Album Slider Shortcode', 'album-and-image-gallery-plus-lightbox'); ?>
											<br/><br/>
											<div><a class="button button-primary aigpl-shrt-map-btn" href="<?php echo esc_url( $shrt_mapper ); ?>"><?php _e('Try Our Shortcode Builder!!', 'album-and-image-gallery-plus-lightbox'); ?></a></div>
										</td>
									</tr>
								</tbody>
							</table>
						</div><!-- .inside -->
					</div><!-- #general -->
				</div><!-- .meta-box-sortables -->
			</div><!-- #post-body-content -->

			<!--Upgrad to Pro HTML -->
			<div id="postbox-container-1" class="postbox-container">
				<div class="meta-box-sortables">

					<div class="postbox wpos-pro-box">
						<h3 class="hndle">
							<span><?php _e('Need Support?', 'album-and-image-gallery-plus-lightbox'); ?></span>
						</h3>
						<div class="inside">
							<p><?php _e('Check plugin document for shortcode parameters and demo for designs.', 'album-and-image-gallery-plus-lightbox'); ?></p>
							<a class="button button-primary wpos-button-full" href="<?php echo esc_url('https://docs.wponlinesupport.com/album-and-image-gallery-plus-lightbox-pro/?utm_source=album_gallery_pro&utm_medium=Album_Gallery&utm_campaign=getting_started'); ?>" target="_blank"><?php _e('Documentation', 'album-and-image-gallery-plus-lightbox'); ?></a>
							<p><a class="button button-primary wpos-button-full" href="<?php echo esc_url('https://demo.wponlinesupport.com/prodemo/album-and-image-gallery-plus-lightbox-pro/?utm_source=album_gallery_pro&utm_medium=Album_Gallery&utm_campaign=getting_started'); ?>" target="_blank"><?php _e('Demo for Designs', 'album-and-image-gallery-plus-lightbox'); ?></a></p>
						</div><!-- .inside -->
					</div><!-- .postbox -->

					<div class="postbox wpos-pro-box">
						<h3 class="hndle">
							<span><?php _e('Need PRO Support?', 'album-and-image-gallery-plus-lightbox'); ?></span>
						</h3>
						<div class="inside">
							<p><?php _e('Hire our experts for WordPress Task.', 'album-and-image-gallery-plus-lightbox'); ?></p>
							<p><a class="button button-primary wpos-button-full" href="<?php echo esc_url('https://www.wponlinesupport.com/wordpress-support/?utm_source=album_gallery_pro&utm_medium=Album_Gallery&utm_campaign=getting_started'); ?>" target="_blank"><?php _e('Know More', 'album-and-image-gallery-plus-lightbox'); ?></a></p>
						</div><!-- .inside -->
					</div><!-- .postbox -->

					<div class="postbox">
						<h3 class="hndle">
							<span><?php _e( 'Help to improve this plugin!', 'album-and-image-gallery-plus-lightbox' ); ?></span>
						</h3>
						<div class="inside">
							<p><?php _e('Enjoyed this plugin? You can help by rate this plugin', 'album-and-image-gallery-plus-lightbox'); ?> <a href="<?php echo esc_url('https://www.wponlinesupport.com/your-review/?utm_source=album_gallery_pro&utm_medium=Album_Gallery&utm_campaign=getting_started'); ?>" target="_blank"><?php _e('5 stars!', 'album-and-image-gallery-plus-lightbox'); ?></a></p>
						</div><!-- .inside -->
					</div><!-- .postbox -->

				</div><!-- .meta-box-sortables -->
			</div><!-- #post-container-1 -->

		</div><!-- #post-body -->
	</div><!-- #poststuff -->
<?php }