<?php
/**
 * Script Class
 *
 * Handles the script and style functionality of plugin
 *
 * @package Album and Image Gallery Plus Lightbox Pro
 * @since 1.0.0
 */

if ( !defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Aigpl_Pro_Script { 

	function __construct() {

		// Action to add script at admin side
		add_action( 'admin_enqueue_scripts', array($this, 'aigpl_pro_admin_script_style') );

		// Action to add style at front side
		add_action( 'wp_enqueue_scripts', array($this, 'aigpl_pro_front_style') );

		// Action to add script at front side
		add_action( 'wp_enqueue_scripts', array($this, 'aigpl_pro_front_script') );

		// Action to add admin script and style when edit with elementor at admin side
		add_action( 'elementor/editor/after_enqueue_scripts', array($this, 'aigpl_pro_admin_builder_script_style') );

		// Action to add admin script and style when edit with SiteOrigin at admin side
		add_action('siteorigin_panel_enqueue_admin_scripts', array($this, 'aigpl_pro_admin_builder_script_style'), 10, 2);

		// Action to add custom css in head
		add_action( 'wp_head', array($this, 'aigpl_pro_add_custom_css'), 20 );
	}

	/**
	 * Function to register admin scripts and styles
	 * 
	 * @package Album and Image Gallery Plus Lightbox Pro
	 * @since 1.4
	 */
	function aigpl_pro_register_admin_assets() {

		global $wp_version;

		// Check wordpress version for older scripts
		$new_ui = $wp_version >= '3.5' ? '1' : '0';

		/* Styles */
		// Registring admin css
		wp_register_style( 'aigpl-pro-admin-style', AIGPL_PRO_URL.'assets/css/aigpl-pro-admin.css', array(), AIGPL_PRO_VERSION );

		/* Scripts */
		// Registring admin script
		wp_register_script( 'aigpl-pro-admin-script', AIGPL_PRO_URL.'assets/js/aigpl-pro-admin.js', array('jquery'), AIGPL_PRO_VERSION, true );
		wp_localize_script( 'aigpl-pro-admin-script', 'AigplProAdmin', array(
																'new_ui' 					=>	$new_ui,
																'img_edit_popup_text'		=> __('Edit Image in Popup', 'album-and-image-gallery-plus-lightbox'),
																'attachment_edit_text'		=> __('Edit Image', 'album-and-image-gallery-plus-lightbox'),
																'img_delete_text'			=> __('Remove Image', 'album-and-image-gallery-plus-lightbox'),
																'remove_gallery_imgs_text'	=> __('Are you sure to remove all images from this gallery!', 'album-and-image-gallery-plus-lightbox'),
																'syntax_highlighting'	=> ( 'false' === wp_get_current_user()->syntax_highlighting ) ? 0 : 1,
															));
	}

	/**
	 * Function to add script at admin side
	 * 
	 * @package Album and Image Gallery Plus Lightbox Pro
	 * @since 1.0.0
	 */ 
	function aigpl_pro_admin_script_style( $hook ) {

		global $wp_query, $typenow;

		$this->aigpl_pro_register_admin_assets();

		// Use minified libraries if SCRIPT_DEBUG is turned off
		$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '_' : '.min';

		if( $typenow == AIGPL_PRO_POST_TYPE ) {

			/* Styles */
			// Enqueue admin script
			wp_enqueue_style( 'aigpl-pro-admin-style' );

			/* Scripts */
			// Gallery Sorting - only when sorting by menu order on the blog listing page
			wp_register_script( 'aigpl-pro-ordering', AIGPL_PRO_URL . 'assets/js/aigpl-pro-ordering.js', array( 'jquery-ui-sortable' ), AIGPL_PRO_VERSION, true );

			// Registring shortcode mapper script
			wp_register_script( 'aigpl-shortcode-mapper', AIGPL_PRO_URL."assets/js/aigpl-shrt-mapper{$suffix}.js", array('jquery'), AIGPL_PRO_VERSION, true );
			wp_localize_script( 'aigpl-shortcode-mapper', 'Aigpl_Shrt_Mapper', array(
																	'ajaxurl' 		=> admin_url( 'admin-ajax.php', ( is_ssl() ? 'https' : 'http' ) ),
																	'shortocde_err' => __("Sorry, Something happened wrong. Kindly please be sure that you have choosen relevant shortocde from the dropdown.", 'album-and-image-gallery-plus-lightbox'),
															));

			// Enqueue required inbuilt sctipt
			wp_enqueue_script( 'jquery-ui-sortable' );
			wp_enqueue_media(); // For media uploader
			wp_enqueue_script( 'aigpl-pro-admin-script' );

			if ( isset( $wp_query->query['orderby'] ) && $wp_query->query['orderby'] == 'menu_order title' ) {
				wp_enqueue_script( 'aigpl-pro-ordering' );
			}

			// Shortcode Builder
			if( $hook == AIGPL_PRO_POST_TYPE.'_page_aigpl-shrt-mapper' ) {
				wp_enqueue_script('shortcode');
				wp_enqueue_script('jquery-ui-accordion');
				wp_enqueue_script('aigpl-shortcode-mapper');
			}

			// WP CSS Code Editor
			wp_enqueue_code_editor( array(
				'type' 			=> 'text/css',
				'codemirror' 	=> array(
					'indentUnit' 	=> 2,
					'tabSize'		=> 2,
					'lint'			=> false,
				),
			) );
		}
	}

	/**
	 * Function to add style at front side
	 * 
	 * @package Album and Image Gallery Plus Lightbox Pro
	 * @since 1.0.0
	 */
	function aigpl_pro_front_style() {

		// Use minified libraries if SCRIPT_DEBUG is turned off
		$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '_' : '.min';

		// Registring and enqueing magnific css
		if( ! wp_style_is( 'wpos-magnific-style', 'registered' ) ) {
			wp_register_style( 'wpos-magnific-style', AIGPL_PRO_URL.'assets/css/magnific-popup.css', array(), AIGPL_PRO_VERSION );
		}

		// Registring and enqueing ilightbox css
		if( ! wp_style_is( 'wpos-ilightbox-style', 'registered' ) ) {
			wp_register_style( 'wpos-ilightbox-style', AIGPL_PRO_URL.'assets/css/lightbox.css', array(), AIGPL_PRO_VERSION );
		}

		// Registring and enqueing slick css
		if( ! wp_style_is( 'wpos-slick-style', 'registered' ) ) {
			wp_register_style( 'wpos-slick-style', AIGPL_PRO_URL.'assets/css/slick.css', array(), AIGPL_PRO_VERSION );
		}

		// Registring and enqueing public css
		wp_register_style( 'aigpl-pro-public-css', AIGPL_PRO_URL."assets/css/aigpl-pro-public{$suffix}.css", array(), AIGPL_PRO_VERSION );

		wp_enqueue_style( 'wpos-magnific-style');
		wp_enqueue_style( 'wpos-ilightbox-style');
		wp_enqueue_style( 'wpos-slick-style');
		wp_enqueue_style( 'aigpl-pro-public-css' );
	}

	/**
	 * Function to add script at front side
	 * 
	 * @package Album and Image Gallery Plus Lightbox Pro
	 * @since 1.0.0
	 */
	function aigpl_pro_front_script() {

		global $post;

		// Use minified libraries if SCRIPT_DEBUG is turned off
		$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '_' : '.min';

		// Registring magnific popup script
		if( ! wp_script_is( 'wpos-magnific-script', 'registered' ) ) {
			wp_register_script( 'wpos-magnific-script', AIGPL_PRO_URL.'assets/js/jquery.magnific-popup.min.js', array('jquery'), AIGPL_PRO_VERSION, true );
		}

		// Registring ilightbox popup script
		if( ! wp_script_is( 'wpos-ilightbox-script', 'registered' ) ) {
			wp_register_script( 'wpos-ilightbox-script', AIGPL_PRO_URL.'assets/js/ilightbox.min.js', array('jquery'), AIGPL_PRO_VERSION, true );
		}

		// Registring slick slider script
		if( ! wp_script_is( 'wpos-slick-jquery', 'registered' ) ) {
			wp_register_script( 'wpos-slick-jquery', AIGPL_PRO_URL.'assets/js/slick.min.js', array('jquery'), AIGPL_PRO_VERSION, true );
		}

		// Register Elementor script
		wp_register_script( 'aigpl-pro-elementor-js', AIGPL_PRO_URL.'assets/js/elementor/aigpl-pro-elementor.js', array('jquery'), AIGPL_PRO_VERSION, true );

		// Registring public script
		wp_register_script( 'aigpl-pro-public-js', AIGPL_PRO_URL."assets/js/aigpl-pro-public{$suffix}.js", array('jquery'), AIGPL_PRO_VERSION, true );
		wp_localize_script( 'aigpl-pro-public-js', 'AigplPro', array(
															'is_mobile' 			=> (wp_is_mobile()) 	? 1 : 0,
															'is_rtl' 				=> (is_rtl()) 			? 1 : 0,
															'ajaxurl' 				=> admin_url( 'admin-ajax.php', ( is_ssl() ? 'https' : 'http' ) ),
															'popup_close_text'		=> esc_html__( 'Close', 'album-and-image-gallery-plus-lightbox' ),
															'popup_prev_text'		=> esc_html__( 'Previous', 'album-and-image-gallery-plus-lightbox' ),
															'popup_next_text'		=> esc_html__( 'Next', 'album-and-image-gallery-plus-lightbox' ),
															'popup_slideshow'		=> esc_html__( 'Slideshow', 'album-and-image-gallery-plus-lightbox' ),
															'popup_fullscreen'		=> esc_html__( 'Enter Fullscreen', 'album-and-image-gallery-plus-lightbox' ),
															'popup_exitfullscreen'	=> esc_html__( 'Exit Fullscreen', 'album-and-image-gallery-plus-lightbox' ),
															'loading_text'			=> esc_html__( 'Please Wait...', 'album-and-image-gallery-plus-lightbox' ),
															'mfp_loading_text'		=> esc_html__( 'Loading image #%curr%...', 'album-and-image-gallery-plus-lightbox' ),
															'mfp_img_error'			=> esc_html__( 'The image could not be loaded.', 'album-and-image-gallery-plus-lightbox' ),
															'mfp_img_counter'		=> esc_html__( '%curr% of %total%', 'album-and-image-gallery-plus-lightbox' ),
														));

		// Enqueue Script for Elementor Preview
		if ( defined('ELEMENTOR_PLUGIN_BASE') && isset( $_GET['elementor-preview'] ) && $post->ID == (int) $_GET['elementor-preview'] ) {

			wp_enqueue_script( 'jquery-masonry' );
			wp_enqueue_script( 'wpos-slick-jquery' );
			wp_enqueue_script( 'wpos-magnific-script' );
			wp_enqueue_script( 'wpos-ilightbox-script' );
			wp_enqueue_script( 'aigpl-pro-public-js' );
			wp_enqueue_script( 'aigpl-pro-elementor-js' );
		}

		// Enqueue Style & Script for Beaver Builder
		if ( class_exists( 'FLBuilderModel' ) && FLBuilderModel::is_builder_active() ) {

			$this->aigpl_pro_register_admin_assets();

			wp_enqueue_style( 'aigpl-pro-admin-style');
			wp_enqueue_script( 'aigpl-pro-admin-script' );
			wp_enqueue_script( 'jquery-masonry' );
			wp_enqueue_script( 'wpos-slick-jquery' );
			wp_enqueue_script( 'wpos-magnific-script' );
			wp_enqueue_script( 'wpos-ilightbox-script' );
			wp_enqueue_script( 'aigpl-pro-public-js' );
		}
	}

	/**
	 * Function to add script at admin side
	 * 
	 * @package Album and Image Gallery Plus Lightbox Pro
	 * @since 1.4
	 */
	function aigpl_pro_admin_builder_script_style() {

		$this->aigpl_pro_register_admin_assets();

		wp_enqueue_style( 'aigpl-pro-admin-style');
		wp_enqueue_script( 'aigpl-pro-admin-script' );
	}

	/**
	 * Add custom css to head
	 * 
	 * @package Album and Image Gallery Plus Lightbox Pro
	 * @since 1.0.0
	 */
	function aigpl_pro_add_custom_css() {

		$custom_css = aigpl_pro_get_option('custom_css');

		if( ! empty( $custom_css ) ) {
			$css  = '<style type="text/css">' . "\n";
			$css .= $custom_css;
			$css .= "\n" . '</style>' . "\n";

			echo $css;
		}
	}
}

$aigpl_pro_script = new Aigpl_Pro_Script();